@@ -59,19 +59,28 @@ class ESOperations:
         """
         if resource == 'ec2' and item_data['State']['Name'] == 'running':
             # Get current price for a given 'running' instance, region and os
+            ec2_type_cost = '0'
             try:
-                ec2_type_price = self.__aws_price.get_price(self.__aws_price.get_region_name(self.__region),
+                # walk around for NA values in eu-central-1
+                # if self.__region == 'eu-central-1':
+                #     curr_region = 'us-east-1'
+                # else:
+                #     curr_region = self.__region
+                ec2_type_cost = self.__aws_price.get_price(self.__aws_price.get_region_name('us-east-1'),
                                                             item_data['InstanceType'], 'Linux')
             except:
-                ec2_cost = '4.6'
+                return 'NA'
             ec2_lanuch_time = item_data['LaunchTime']
             d1 = datetime.strptime(ec2_lanuch_time, "%Y-%m-%dT%H:%M:%S+00:00")
             d2 = datetime.strptime(strftime("%Y-%m-%dT%H:%M:%S+00:00"), "%Y-%m-%dT%H:%M:%S+00:00")
             diff = d2 - d1
             diff_in_hours = diff.total_seconds() / 3600
-            ec2_cost = round(float(ec2_type_price) * diff_in_hours, 3)
+            ec2_cost = round(float(ec2_type_cost) * diff_in_hours, 3)
             return ec2_cost
+        elif resource == 'ec2' and item_data['State']['Name'] != 'running':
+            return '0'
         elif resource == 'ebs':
+            ebs_monthly_cost = '0'
             if item_data['VolumeType'] == 'gp2':
                 ebs_monthly_cost = 0.1 * item_data['Size']
             elif item_data['VolumeType'] == 'io1':
@@ -90,7 +99,6 @@ class ESOperations:
         :param es_add_items:
         :return:
         """
-
         # fetch data from s3 per region/policy
         data = self.__get_last_s3_policy_content(policy=policy, file_name=s3_json_file)
         if data:
@@ -118,15 +126,15 @@ class ESOperations:
                             if val['Value'] == 'owned':
                                 cluster_owned = val['Key']
                     # ec2
-                    # instance id | name | State | instance type | cost($) | cluster id
+                    # name | instance id  | instance type | launch time | state  | cost($) | cluster id
                     if item.get('InstanceId'):
                         ec2_cost = self.__get_resource_cost(resource='ec2', item_data=item)
-                        data_dict['resources_list'].append(f"{item['InstanceId']} | {ec2_ebs_name} | {item['State']['Name']} | {item['InstanceType']} | {ec2_cost} | {cluster_owned} ")
+                        data_dict['resources_list'].append(f"{ec2_ebs_name} | {item['InstanceId']} | {item['InstanceType']} | {item['LaunchTime'][:-9].replace('T', ' ')} | {item['State']['Name']}  | {ec2_cost} | {cluster_owned} ")
                     # ebs
-                    # volume id | name | volume type | size(gb) | cost($/month)
+                    # name | volume id | volume type | size(gb) | cost($/month)
                     if item.get('VolumeId'):
                         ebs_monthly_cost = self.__get_resource_cost(resource='ebs', item_data=item)
-                        data_dict['resources_list'].append(f"{item['VolumeId']} | {ec2_ebs_name} | {item['VolumeType']} | {item['Size']} | {ebs_monthly_cost}")
+                        data_dict['resources_list'].append(f"{ec2_ebs_name} | {item['VolumeId']} | {item['VolumeType']} | {item['Size']} | {ebs_monthly_cost}")
                     # gitleaks
                     if item.get('leakURL'):
                         gitleaks_leakurl = item.get('leakURL')
